# 6.7.2.3版本

1. 修复在Linux系统上的编译打包问题

# 6.7.2.2版本

1. 适配vnpy框架4.0版本

# 6.7.2.1版本

1. 升级pybind11封装工具库版本，支持Python 3.11/3.12

# 6.7.2.0版本

1. 替换最新版本dll和so，升级到6.7.2
2. 类型声明使用内置数据类型

# 6.6.9.1版本

1. 替换最新版本dll和so，升级到6.6.9

# 6.6.7.3版本

1. 替换最新版本dll，修复openctp升级导致的资金不显示的问题

# 6.6.7.2版本

1. 添加广州期货交易所枚举值字段支持
2. 替换最新版本dll和so，修复openctp升级导致的资金不显示的问题

# 6.6.7.1版本

1. 替换dll，增加平昨支持

# 6.6.7.0版本

1. 使用zoneinfo替换pytz库
2. 调整安装脚本setup.cfg，添加Python版本限制

# 6.5.1.3版本

1. 修复sdist打包缺失lib文件的问题
2. 完善函数和变量的类型声明

# 6.5.1.2版本

1. 调整安装脚本setup.py，支持Windows下安装时根据Python版本进行编译
2. 调整接口初始化时，接口名称的赋值方式

# 6.5.1.1版本

1. 增加行情TickData的成交额turnover字段
2. 增加对上交所和深交所股票模拟交易的支持
